#!gmake

## Copyright (C) 2008 Philippe Dreuw
#  
#  @file    Makefile
#  @author  Philippe Dreuw <dreuw@cs.rwth-aachen.de>
#  @brief   Makefile config
#  
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License as
#  published by the Free Software Foundation; either version 2 of the
#  License, or (at your option) any later version.
# 
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#  USA
#  
# $Id: Config.make,v 1.3 2008-02-25 15:54:28 dreuw Exp $ 
#  

BINDIR          =
GCC_VERSION     =

# -----------------------------------------------------------------------------
# Compiler
CC              = $(BINDIR)gcc$(GCC_VERSION)
LD              = $(BINDIR)g++$(GCC_VERSION)
CXX             = $(BINDIR)g++$(GCC_VERSION)
CXXLD           = $(BINDIR)g++$(GCC_VERSION)

CPPFLAGS        += $(SYS_INCLUDES)

CCFLAGS         =                 # common for C and C++
CXXFLAGS        = $(CCFLAGS)      # options for C++ compiler
CFLAGS          = $(CCFLAGS)      # options for C compiler

OBJDIR=.build
# -----------------------------------------------------------------------------



# -----------------------------------------------------------------------------
# system Libraries 

# z lib, png
LDFLAGS         += -lz -lpng

# artgable2
LDFLAGS         += -largtable2

# FFmpeg
INCLUDES        += $(shell pkg-config --cflags libavcodec --cflags libavformat --cflags libavutil)
LDFLAGS         += $(shell pkg-config --libs libavcodec --libs libavformat --libs libavutil)

#INCLUDES += -I$(HOME)/include


# -----------------------------------------------------------------------------
# compiler options 
DEFINES         += -D_GNU_SOURCE
CCFLAGS         += -pipe
CCFLAGS         += -funsigned-char
CCFLAGS         += -fno-exceptions
CXXFLAGS        += -fpermissive
CFLAGS          += -std=c99
CXXFLAGS        += -std=gnu++98
CCFLAGS         += -pedantic
CCFLAGS         += -Wall
CCFLAGS         += -ansi
CCFLAGS         += -Wno-long-long

ifeq ($(COMPILE),debug)
  CCFLAGS         += -g
  DEFINES         += -D_GLIBCXX_DEBUG
  DEFINES         += -DDEBUG
endif

CPPFLAGS        += $(DEFINES)
CPPFLAGS        += $(INCLUDES)

# Generate code for Pentium Pro and beyond.
CCFLAGS         += -march=i686
CCFLAGS         += -ffast-math
ifeq ($(COMPILE),debug)
CCFLAGS         += -O0
else
CCFLAGS         += -O2
endif

# -----------------------------------------------------------------------------
# enable compiler cache
CCACHE          = ccache
CCACHE_UNIFY    = 1
CCACHE_DIR      = /tmp
CCACHE_UMASK    = 000
CC              := $(CCACHE) $(CC)
CXX             := $(CCACHE) $(CXX)

# -----------------------------------------------------------------------------
MAKE            = make
MAKEDEPEND      = makedepend -v -D__GNUC__=3 -D__GNUC_MINOR__=3
MAKEINDEX       = makeindex
