/** Copyright (C) 2008 Philippe Dreuw
 * 
 * @file    Functor.hh
 * @author  Philippe Dreuw <dreuw@cs.rwth-aachen.de>
 * @brief   Provides access to member functions.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 * 
 * $Id: Functor.hh,v 1.6 2009-11-11 11:04:07 dreuw Exp $
 * 
 */
#ifndef FUNCTOR_HH
#define FUNCTOR_HH

#if defined FFMPEG_VERSION && FFMPEG_VERSION >= 50
#include <libavcodec/avcodec.h>
#else
#include <ffmpeg/avcodec.h>
#endif

#include <iostream>

// abstract base class
class TFunctor
{
public:
    TFunctor() {}
    virtual ~TFunctor() {}

    // two possible functions to call member function. virtual cause derived
    // classes will use a pointer to an object and a pointer to a member function
    // to make the function call
    virtual void operator()(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) = 0;  // call using operator
    virtual void Call(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) = 0;        // call using function
};


// derived template class
template <class TClass> 
class TSpecificFunctor : 
    public TFunctor
{
private:
    void (TClass::*fpt)(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame);   // pointer to member function
    TClass* pt2Object;                                                                                    // pointer to object

public:
    // constructor - takes pointer to an object and pointer to a member and stores
    // them in two private variables
    TSpecificFunctor(TClass* _pt2Object, void(TClass::*_fpt)(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame)) { 
        pt2Object = _pt2Object;  
        fpt=_fpt; 
    };
    virtual ~TSpecificFunctor() {}

    // override operator "()"
    virtual void operator()(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) { 
        (*pt2Object.*fpt)(pFrame, width, height, iFrame); // execute member function
    };              

    // override function "Call"
    virtual void Call(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) { 
        (*pt2Object.*fpt)(pFrame, width, height, iFrame); // execute member function
    };             
};

#endif //FUNCTOR_HH
