/** Copyright (C) 2008 Philippe Dreuw
 * 
 * @file    Image.cc
 * @author  Philippe Dreuw <dreuw@cs.rwth-aachen.de>
 * @brief   Image class.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 * 
 * $Id: Image.cc,v 1.2 2008-02-25 15:54:28 dreuw Exp $
 * 
 */
#include "Image.hh"

using namespace Image;

void PngImage::save(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) {
    sprintf(filename_, "frame%06d.png", iFrame);
    write_png(filename_, pFrame->data[0], width, height, 8, 3);
}

void PpmImage::save(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) {
    // Open file
    sprintf(filename_, "frame%06d.ppm", iFrame);       
    pFile_=fopen(filename_, "wb");
    if(pFile_==NULL)
        return;
    
    // Write header
    fprintf(pFile_, "P6 %d %d 255\n", width, height);
    
    // Write pixel data
    int colorWitdh=width*3;
    for(size_t y=0; y<height; ++y)
        fwrite(pFrame->data[0]+y*pFrame->linesize[0], 1, colorWitdh, pFile_);
    
    // Close file
    fclose(pFile_);
}


