/** Copyright (C) 2008 Philippe Dreuw
 * 
 * @file    Image.hh
 * @author  Philippe Dreuw <dreuw@cs.rwth-aachen.de>
 * @brief   Image class.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 * 
 * $Id: Image.hh,v 1.5 2009-11-11 11:04:07 dreuw Exp $
 * 
 */
#ifndef IMAGE_IMAGE_HH
#define IMAGE_IMAGE_HH

#include "pngfile.h"
#if defined FFMPEG_VERSION && FFMPEG_VERSION >= 50
#include <libavcodec/avcodec.h>
#else
#include <ffmpeg/avcodec.h>
#endif

namespace Image {

    class Image 
    {
    protected:
        char filename_[32];
    public:
        Image() {}
        virtual ~Image() {}
        virtual void save(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame) = 0;    
    };
       
    class PngImage : 
        public Image 
    {
    public:
        PngImage(){};
        
        void save(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame);
    };
    
    /** writes an ASCII ppm image to file */
    class PpmImage :
        public Image 
    {
    private:
        FILE *pFile_;
    public:
        PpmImage(){};
        
        void save(AVFrame *pFrame, unsigned int width, unsigned int height, unsigned int iFrame);
    };

} // namespace Image

#endif //IMAGE_IMAGE_HH
