# Project:      ffmpegReader
# File:		Rules.make - generic parts of build environment
# Revision:     $Id: Rules.make,v 1.2 2007-03-07 18:18:04 dreuw Exp $

# -----------------------------------------------------------------------------
subdirs_%:
	@sh -c 'set -e; for i in $(SUBDIRS); do $(MAKE) -C $$i $*; done'

recursive_%:	%
	@sh -c 'set -e; for i in $(SUBDIRS); do $(MAKE) -C $$i $@; done'

# -----------------------------------------------------------------------------
# cleaning
clean:
	find . -name "*~" 			| xargs rm -f
	find . -type d -path "*/$(OBJDIR)"	| xargs rm -fr
	find . -type f -name "core" 		| xargs rm -f
	find . -regex '.*\.\(c\|hh\|cc\).bprof' | xargs rm -f
	find . -name "[bg]mon.out" 		| xargs rm -f
	find . -name "*.bak" 			| xargs rm -f
	find . -name ".gdb_history" 		| xargs rm -f

distclean:	clean
	find . -type d -name '.build'		| xargs rm -fr
	rm -f $(TARGETS)

clean-depend:
	find . -type f -name "*.d" -print | xargs rm -f

clean-libs:
	find . -type f -name "*.$(a)" -print | xargs rm -f

clean-images:
	rm -f *.png *.ppm

# -----------------------------------------------------------------------------
# C/C++ compilation

$(OBJDIR)/%.o: %.asm
	@mkdir -p $(OBJDIR)
	$(ASM) $(ASMFLAGS) -o $@ $<

$(OBJDIR)/%.o: %.c
	@mkdir -p $(OBJDIR)
	@echo compiling $<
	@$(CC) $(CPPFLAGS) $(CFLAGS) -c -o $@ $<

$(OBJDIR)/%.o: %.cc
	@mkdir -p $(OBJDIR)
	@echo compiling $<
	@$(CXX) $(CPPFLAGS) $(CXXFLAGS) -c -o $@ $<

$(OBJDIR)/%.pic: %.c
	@mkdir -p $(OBJDIR)
	@echo compiling $<
	@$(CC) $(CPPFLAGS) $(CFLAGS) -fPIC -c -o $@ $<

$(OBJDIR)/%.pic: %.cc
	@mkdir -p $(OBJDIR)
	@echo compiling $<
	@$(CXX) $(CPPFLAGS) $(CXXFLAGS) -fPIC -c -o $@ $<

$(OBJDIR)/%.d: %.c
	@mkdir -p $(OBJDIR)
	@$(MAKEDEPEND) -Y $(CPPFLAGS) $< -f - 2>/dev/null \
	| sed 's|\($*\.o\):|$(OBJDIR)/\1 $@:|' \
	>$@ \
	; [ -e $@ ] || rm -f $@

$(OBJDIR)/%.d: %.cc
	@mkdir -p $(OBJDIR)
	@$(MAKEDEPEND) -Y $(CPPFLAGS) $< -f - 2>/dev/null \
	| sed 's|\($*\.o\):|$(OBJDIR)/\1 $@:|' \
	>$@ \
	; [ -e $@ ] || rm -f $@ 2>&1 /dev/null

$(OBJDIR)/%.i: %.c
	@mkdir -p $(OBJDIR)
	@echo preprocessong $<
	@$(CC) $(CPPFLAGS) $(CFLAGS) -E -o $@ $<

$(OBJDIR)/%.ii: %.cc
	@mkdir -p $(OBJDIR)
	@echo preprocessong $<
	@$(CC) $(CPPFLAGS) $(CXXFLAGS) -E -o $@ $<

$(OBJDIR)/%.ss: %.cc
	@mkdir -p $(OBJDIR)
	@echo preprocessong $<
	@$(CC) $(CPPFLAGS) $(CXXFLAGS) -S -o $@ $<

moc_%.cc: %.hh
	$(MOC) $< -o $@

# -----------------------------------------------------------------------------
# document processing
%.dvi: %.tex
	$(LATEX) $<

# -----------------------------------------------------------------------------
INSTALL	= install -s -p
